@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Tools for ploting the data from NetCDF file, using only numpy and matplotlib libs.
+# Tools for ploting the _data from NetCDF file, using only numpy and matplotlib libs.
 
 import matplotlib.pyplot as plt
 import cartopy.crs as ccrs
@@ -40,7 +40,7 @@ def lon_lat_plot_map(
     savefig=False,
     filename="saved_fig.png",
 ):
-    """Plot a 2D map of the data with cartopy.
+    """Plot a 2D map of the _data with cartopy.
 
     Parameters
     ----------
@@ -86,6 +86,7 @@ def lon_lat_plot_map(
     None
         Plots the map in ax
     """
+
     # Obtain 2D variable to plot
     var2D = _var2d(var, lon_axis, lat_axis)
 
@@ -165,7 +166,7 @@ def scatterplot_map(
     fig_ax : [type], optional
         [description], by default None
     color : str, optional
-        color of the points, can also be a 1D list of the same length than the data, by default 'k'
+        color of the points, can also be a 1D list of the same length than the _data, by default 'k'
     size : float, optional
         size of the points, by default 1
     title : str, optional
@@ -212,73 +213,43 @@ def scatterplot_map(
     return None
 
 
-def plot_tracks(
-    tracks,
-    lon_col="lon",
-    lat_col="lat",
-    id_col="track_id",
-    id=None,
-    projection=ccrs.PlateCarree(central_longitude=180.0),
-    intensity_col="wind",
-    fig_ax=None,
-    figsize=[10, 15],
-    cmap="RdYlGn_r",
-    draw_lines=True,
-):
-    """
-    Function to plot tracks from the tracks.txt file generated by TempestExtremes
+def plot_hist2d(hist, axis, bounds, shrink_cbar=0.8):
+    norm = BoundaryNorm(bounds, len(bounds) - 1, clip=True)
+    cmap_reds = plt.cm.get_cmap("magma_r", len(bounds))
+    colors = list(cmap_reds(np.arange(len(bounds))))
+    colors[0] = "white"
+    cmap = ListedColormap(colors[:-1], "")
+    cmap.set_over(colors[-1])
 
-    Parameters
-    ----------
-    cmap
-    tracks: pandas DataFrame of tracks points
-    id_col: name of the column in track with cyclones id
-    id: id of the track(s) to plot
-    projection: ccrs projection to use for the plot
-    intensity_col: name of the column in tracks to use as color
-
-    Returns
-    -------
-    None. Produces a plot.
-    """
-
-    if type(id) == str:
-        id = [id]
-    if (type(id) == list) | (type(id) == np.ndarray):
-        tracks = tracks[tracks[id_col].isin(id)]
-
-    # Plotting
-    if fig_ax == None:
-        fig = plt.figure(figsize=figsize)
-        ax = plt.axes(projection=projection)
-        ax.coastlines()
-        ax.gridlines(draw_labels=False)
-        ax.add_feature(cartopy.feature.OCEAN, zorder=0, facecolor="azure")
-        ax.add_feature(cartopy.feature.LAND, zorder=0, edgecolor="black")
-    else:
-        fig, ax = fig_ax
-
-    if draw_lines:
-        for id in tracks[id_col].unique():
-            c = tracks[tracks[id_col] == id]
-            lon = c[lon_col].values
-            lat = c[lat_col].values
-            ax.plot(
-                lon, lat, transform=ccrs.PlateCarree(), c="k", alpha=0.7, linewidth=0.5
-            )
-
-    sns.scatterplot(
-        data=tracks,
-        x=lon_col,
-        y=lat_col,
-        hue=intensity_col,
-        ax=ax,
+    p = hist.plot(
+        ax=axis,
         transform=ccrs.PlateCarree(),
-        palette=cmap,
-        size=intensity_col,
-        sizes=(4, 20),
+        cmap=cmap,
+        norm=norm,
+        extend="max",
+        cbar_kwargs={"shrink": shrink_cbar},
     )
-    return fig, ax
+    axis.coastlines()
+    axis.set_global()
+
+
+def plot_diff(diff, axis, range=2.0, mid=0.125, delta=0.25, shrink_cbar=0.8):
+    bounds = (
+        list(np.arange(-range, 0, delta))
+        + [-mid, mid]
+        + list(np.arange(delta, range + delta, delta))
+    )
+    norm = BoundaryNorm(bounds, len(bounds) - 1)
+    p = diff.plot(
+        ax=axis,
+        transform=ccrs.PlateCarree(),
+        cmap="bwr",
+        norm=norm,
+        cbar_kwargs={"shrink": shrink_cbar},
+        extend="both",
+    )
+    axis.coastlines()
+    axis.set_global()
 
 
 zooms = {
