@@ -215,7 +215,7 @@ def storm_stats(tracks):
     return storms
 
 
-def propagation_speeds(tracks):
+def propagation_speeds(tracks): # TODO : Probleme quand un point traverse le méridien de greenwhich
     """
     Return the propagation speed of each track
 
